/*!
 * Copyright © 2005-2025 Hyland Software, Inc. and its affiliates. All rights reserved.
 *
 * Alfresco Example Content Application
 *
 * This file is part of the Alfresco Example Content Application.
 * If the software was purchased under a paid Alfresco license, the terms of
 * the paid license agreement will prevail. Otherwise, the software is
 * provided under the following open source license terms:
 *
 * The Alfresco Example Content Application is free software: you can redistribute it and/or modify
 * it under the terms of the GNU Lesser General Public License as published by
 * the Free Software Foundation, either version 3 of the License, or
 * (at your option) any later version.
 *
 * The Alfresco Example Content Application is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the
 * GNU Lesser General Public License for more details.
 *
 * You should have received a copy of the GNU Lesser General Public License
 * from Hyland Software. If not, see <http://www.gnu.org/licenses/>.
 */
import { NodeEntry, NodePaging } from '@alfresco/js-api';
import { NodeContentTree } from './node-content-tree';
export declare class NodesApi {
    private apiService;
    constructor();
    static initialize(userName: string, password?: string): Promise<NodesApi>;
    createFolder(name: string, parentId?: string, title?: string, description?: string, author?: string, aspectNames?: string[]): Promise<NodeEntry | null>;
    createFile(name: string, parentId?: string, title?: string, description?: string, author?: string, majorVersion?: boolean, aspectNames?: string[]): Promise<NodeEntry>;
    createFiles(names: string[], relativePath?: string): Promise<NodePaging>;
    createFolders(names: string[], relativePath?: string): Promise<NodePaging>;
    deleteDeletedNode(name: string): Promise<void>;
    private createNode;
    renameNode(nodeId: string, newName: string): Promise<NodeEntry | null>;
    /**
     * Delete multiple nodes.
     * @param nodeIds The list of node IDs to delete.
     * @param permanent Delete permanently, without moving to the trashcan? (default: true)
     */
    deleteNodes(nodeIds: string[], permanent?: boolean): Promise<any>;
    /**
     * Delete all nodes of the currently logged in user
     * @param userNodeId The id of User node, all child nodes of "userNodeId" will be gathered as a list and deleted ( e.g.: "-my-" - User Homes folder)
     */
    deleteCurrentUserNodes(): Promise<void>;
    lockNodes(nodeIds: string[], lockType?: string): Promise<void>;
    unlockNodes(nodeIds: string[]): Promise<void>;
    createContent(content: NodeContentTree, relativePath?: string): Promise<NodePaging>;
    getNodeById(id: string): Promise<NodeEntry | null>;
    getNodeIdFromParent(name: string, parentId: string): Promise<string>;
    private getNodeChildren;
    deleteNodeById(id: string, permanent?: boolean): Promise<void>;
    cleanupNodeTemplatesItems(nodeNames: string[]): Promise<void>;
    cleanupSpaceTemplatesItems(nodeNames: string[]): Promise<void>;
    getNodeTemplatesFolderId(): Promise<string>;
    getSpaceTemplatesFolderId(): Promise<string>;
    private getDataDictionaryId;
    setGranularPermission(nodeId: string, inheritPermissions: boolean, username: string, role: string): Promise<NodeEntry | null>;
    removeUserAccessOnNodeTemplate(nodeName: string): Promise<NodeEntry>;
    removeUserAccessOnSpaceTemplate(nodeName: string): Promise<NodeEntry>;
    setInheritPermissions(nodeId: string, inheritPermissions: boolean): Promise<NodeEntry | null>;
    private addAspects;
    createFileLink(originalNodeId: string, destinationId: string): Promise<NodeEntry | null>;
    createFolderLink(originalNodeId: string, destinationId: string): Promise<NodeEntry | null>;
    createLinkToFileName(originalFileName: string, originalFileParentId: string, destinationParentId?: string): Promise<NodeEntry>;
    createLinkToFolderName(originalFolderName: string, originalFolderParentId: string, destinationParentId?: string): Promise<NodeEntry>;
    getNodeProperty(nodeId: string, property: string): Promise<string>;
    isFileShared(nodeId: string): Promise<boolean>;
    private getLockType;
    isFileLockedWrite(nodeId: string): Promise<boolean>;
}
